#encoding:utf-8
from distutils.core import setup

setup(
    name='WuSir',
    version='1.0',
    description='模拟测试代码发布。',
    author='wusir',
    author_email='whsoftware@gmail.com',
    py_modules=['rclone']
)